@@ -13,9 +13,11 @@ class Config:
   arflags     = "rc"              # ar flags
   ldflags_c   = ""                # loader flags when main program is in C
   ldflags_fc  = ""                # loader flags when main program is in Fortran
+  ld_fcmain   = ""                # the option to link C main with fortran linker
   ccflags     = "-O2"
   fcflags     = "-O2"
   noopt       = "-O0"
+  lapinstalled = 0
 
   def __init__(self, version):
     self.version = version
