@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.4.1
+# @version 2.4.6
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -43,14 +43,20 @@ class Framework:
     plasmalib    = ""                        # plasma library
     plasmaurl    = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs/plasma.tar.gz"
     urlbase      = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs"
-    versions     = ("2.4.1", "2.4.0", "2.3.1", "2.3.0", "2.2.0", "2.1.0", "2.0.0", "1.0.1", "1.0.0")
+    versions     = ("2.4.6", "2.4.5", "2.4.2", "2.4.1", "2.4.0", 
+                    "2.3.1", "2.3.0", 
+                    "2.2.0", "2.1.0", 
+                    "2.0.0", 
+                    "1.0.1", "1.0.0")
     oldversions  = ("2.1.0", "2.0.0", "1.0.1", "1.0.0") # Releases from version which need the internal cblas and lapack
+    lapversion   = "lapack-3.4.1"
     ranlib       = ""                        # the ranlib command
     clean        = 0
     nbcores      = 2
     src          = 0
     installerdir = ""
     verbose      = 0
+    lapackinstalled = 0;
 
     def __init__(self, argv, config):
 
@@ -141,6 +147,7 @@ You can specify it using the --fc flag."""
             else:
                 print 'LAPACK library is... Check if included in Blas library'
         else:
+            self.downlapack = -1
             print 'LAPACK library is... ', self.config.lapacklib
 
         if (self.downlapc == 2) :
@@ -237,9 +244,9 @@ You can specify it using the --fc flag."""
 
    --src               : Generates a make.inc for PLASMA developpers with
                          options given. If some external libraries are
-                         not available, they are automatically download
-                         and install in prefix directory.
-                         Testings are also desactivated by default.
+                         not available, they are automatically downloaded
+                         and installed in the prefix directory.
+                         Testing step is also deactivated by default.
    """ % self.config.version
           print "="*40
           sys.exit()
@@ -393,7 +400,7 @@ You can specify it using the --fc flag."""
             }\n""")
 
         # compile
-        ccomm = self.config.cc+" "+self.config.ccflags+" -o tmpc "+os.path.join(os.getcwd(),"tmpc.c")
+        ccomm = self.config.cc+" "+self.config.ccflags+" "+self.config.ldflags_c+" -o tmpc "+os.path.join(os.getcwd(),"tmpc.c")
         (output, error, retz) = runShellCommand(ccomm)
 
         if retz:
@@ -429,7 +436,7 @@ You can specify it using the --fc flag."""
       end\n""")
 
         # compile
-        fcomm = self.config.fc+' '+self.config.fcflags+' -o tmpf '+'tmpf.f'
+        fcomm = self.config.fc+' '+self.config.fcflags+" "+self.config.ldflags_fc+' -o tmpf '+'tmpf.f'
         (output, error, retz) = runShellCommand(fcomm)
 
         if retz:
@@ -472,7 +479,7 @@ You can specify it using the --fc flag."""
       void C_INTFACE(int *i){fprintf(stdout, \"-DUPCASE\");fflush(stdout);}\n""")
 
         ccomm = self.config.cc+' '+self.config.ccflags+' -c tmpc.c -o tmpc.o'
-        fcomm = self.config.fc+' '+self.config.fcflags+' tmpf.f tmpc.o -o xintface'
+        fcomm = self.config.fc+' '+self.config.fcflags+' '+self.config.ldflags_fc+' tmpf.f tmpc.o -o xintface'
 
         (output, error, retz) = runShellCommand(ccomm)
         if retz:
@@ -530,7 +537,7 @@ You can specify it using the --fc flag."""
 
         ccomm = self.config.cc+' '+self.config.ccflags+' '+self.mangling+' -c -o tmpc.o tmpc.c'
         fcomm = self.config.fc+' '+self.config.fcflags+' -c -o tmpf.o tmpf.f'
-        lcomm = self.config.fc+' '+self.config.ldflags_c+' -o lnk tmpf.o tmpc.o'
+        lcomm = self.config.fc+' '+self.config.ldflags_fc+' '+self.config.ld_fcmain+' -o lnk tmpf.o tmpc.o'
 
         (output, error, retz) = runShellCommand(ccomm)
         if retz:
@@ -631,18 +638,24 @@ You can specify it using the --fc flag."""
             # for the linking and the -mp flag to maintain the
             # floating-point precision
             self.config.fcflags    += ' -diag-disable vec -fltconsistency -fp_port'
-            self.config.ldflags_c  += ' -nofor_main'   # used to link
+            self.config.ldflags_c  += ' '   # used to link
             self.config.ldflags_fc += ' '
+            self.config.ld_fcmain   = ' -nofor_main'
             self.config.noopt      += ' -mp'
+            self.testing = 0; # Cannot compile lintest with fc_main option
             print 'Intel'
         elif self.fc_is_gnu():
             print 'GNU'
+            self.config.ld_fcmain   = ''
         elif self.fc_is_xlf():
             self.config.fcflags    += ' -qstrict -qthreaded'
+            self.config.ld_fcmain   = ''
             print 'IBM'
         elif self.fc_is_pgi():
-            self.config.ldflags_c  += ' -Mnomain'
+            self.config.ldflags_c  += ''
             self.config.ldflags_fc += ''
+            self.config.ld_fcmain   = ' -Mnomain'
+            self.testing = 0; # Cannot compile lintest with fc_main option
         else:
             print 'unknown'
 
@@ -786,8 +799,6 @@ You can specify it using the --fc flag."""
 
     def resume(self):
 
-        cwd = os.getcwd()
-
         if self.src :
             print """
 ******************************************************
@@ -799,7 +810,7 @@ You can copy the following file in your src directory to compile
 PLASMA :\n"""+os.path.join(self.build,'make.inc')+"""\n
 
 WARNING: the prefix directory has been set to same directory than
-external libraies.  If you want to install PLASMA in another
+external libraries.  If you want to install PLASMA in another
 directory, don't forget to change it.
 
 We strongly recommend the use of hwloc library for a better binding of
@@ -860,10 +871,7 @@ WARNING: the following environment variables have been
         print "Cleaning up...",
         sys.stdout.flush()
 
-        cwd = os.getcwd()
         builddir = os.path.join(self.build)
-        #libdir   = os.path.join(cwd,'lib')
-        #logdir   = os.path.join(cwd,'log')
 
         comm = 'rm -rf '+builddir
         #+' '+libdir+' '+logdir
