@@ -8,7 +8,7 @@
 #  PLASMA is a software package provided by Univ. of Tennessee,
 #  Univ. of California Berkeley and Univ. of Colorado Denver
 #
-# @version 2.4.1
+# @version 2.4.6
 # @author Julie Langou
 # @author Mathieu Faverge
 # @date 2010-11-15
@@ -22,7 +22,7 @@ import shutil
 import framework
 
 class Lapcwrapper(framework.Framework):
-    lapcurl     = "http://icl.cs.utk.edu/projectsfiles/plasma/pubs/lapacke-3.3.0.tgz"
+    lapackurl = "http://www.netlib.org/lapack/lapack.tgz"
 
     """ This class takes care of the LAPACK C interface installation. """
     def __init__(self, config, plasma):
@@ -87,8 +87,8 @@ int main(int argc, char*agv[]) {
                 print "no"
             return -1;
 
-        ldflg = self.config.ldflags_c+' '+self.config.lapclib+' '+self.config.lapacklib+' '+self.config.blaslib+' -lm'
-        ccomm = self.config.fc+' -o tmpc '+'tmpc.o '+self.config.lapackinc+' '+ldflg
+        ldflg = self.config.ld_fcmain+' '+self.config.ldflags_fc+' '+self.config.lapclib+' '+self.config.lapacklib+' '+self.config.blaslib+' -lm'
+        ccomm = self.config.fc+' -o tmpc tmpc.o '+ldflg
         (output, error, retz) = runShellCommand(ccomm)
         if(retz != 0):
             if self.plasma.verbose:
@@ -133,80 +133,120 @@ The reference LAPACK C interface is being installed.
         if not os.path.isdir(os.path.join(os.getcwd(),'log')):
             os.mkdir(os.path.join(os.getcwd(),'log'))
 
-        # Check if lapacke.tgz is already present in the working dir
-        # otherwise download it
-        if not os.path.isfile(os.path.join(os.getcwd(),getURLName(self.lapcurl))):
-            print "Downloading reference LAPACK C interface...",
-            downloader(self.lapcurl,self.downcmd)
-            print "done"
-
-        # unzip and untar
-        print 'Unzip and untar reference LAPACK C interface...',
-        comm = 'gunzip -f lapacke-3.3.0.tgz'
-        (output, error, retz) = runShellCommand(comm)
-        if retz:
-            print '\n\nLAPCWRAPPER: cannot unzip lapacke.tgz'
-            print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
-            sys.exit()
-
-        comm = 'tar xf lapacke-3.3.0.tar'
-        (output, error, retz) = runShellCommand(comm)
-        if retz:
-            print '\n\nLAPCWRAPPER: cannot untar lapacke.tar'
-            print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
-            sys.exit()
-        os.remove('lapacke-3.3.0.tar')
-        print 'done'
+        if self.config.lapinstalled == 0:
+            # Check if lapacke.tgz is already present in the working dir
+            # otherwise download it
+            if not os.path.isfile(os.path.join(os.getcwd(),getURLName(self.lapackurl))):
+                print "Downloading reference LAPACK C interface...",
+                downloader(self.lapcurl,self.downcmd)
+                print "done"
+            
+            # unzip and untar
+            print 'Unzip and untar reference LAPACK C interface...',
+            comm = 'gunzip -f lapack.tgz'
+            (output, error, retz) = runShellCommand(comm)
+            if retz:
+                print '\n\nLAPCWRAPPER: cannot unzip lapack.tgz'
+                print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
+                sys.exit()
+            
+            comm = 'tar xf lapack.tar'
+            (output, error, retz) = runShellCommand(comm)
+            if retz:
+                print '\n\nLAPCWRAPPER: cannot untar lapack.tar'
+                print 'stderr:\n','*'*40,'\n',comm,'\n',error,'\n','*'*40
+                sys.exit()
+            os.remove('lapack.tar')
+            print 'done'
 
         # change to LAPACK C interface dir
-        os.chdir(os.path.join(os.getcwd(),'lapacke-3.3.0'))
-        sdir = os.getcwd()
+        os.chdir(os.path.join(os.getcwd(), self.lapversion))
 
         # Write Makefile.in
         writefile('make.inc', """
-# make.inc (Plasma Installer)
+# -*- Makefile generated by PLASMA installer -*-
+####################################################################
+#  LAPACK make include file.                                       #
+#  LAPACK, Version 3.4.0                                           #
+#  April 2012                                                      #
+####################################################################
 #
-#-----------------------------------------------------------------------------
-# Shell
-#-----------------------------------------------------------------------------
 SHELL = /bin/sh
-
-#-----------------------------------------------------------------------------
-# Platform
-#-----------------------------------------------------------------------------
-
-PLAT = """+self.plat+"""
-
-#-----------------------------------------------------------------------------
-# Compilers
-#-----------------------------------------------------------------------------
-
-CC      = """+self.config.cc+""" """+self.config.ccflags+""" """+self.mangling+"""
-FORTRAN = """+self.config.fc+""" """+self.config.fcflags+"""
-LOADER  = $(CC)
-
-#-----------------------------------------------------------------------------
-# Flags for Compilers
-#-----------------------------------------------------------------------------
-
-OPTS  =
-NOOPT =
-
-#-----------------------------------------------------------------------------
-# Archive programs and flags
-#-----------------------------------------------------------------------------
-
-ARCH      = ar
-ARCHFLAGS = """+self.config.arflags+"""
-RANLIB    = """+self.config.ranlib+"""
-
-LAPACKE   = liblapacke.a
+#
+#  Modify the FORTRAN and OPTS definitions to refer to the
+#  compiler and desired compiler options for your machine.  NOOPT
+#  refers to the compiler options desired when NO OPTIMIZATION is
+#  selected.  Define LOADER and LOADOPTS to refer to the loader and
+#  desired load options for your machine.
+#
+FORTRAN  = """+self.config.fc+"""
+OPTS     = """+self.config.fcflags+"""
+DRVOPTS  = $(OPTS)
+NOOPT    = """+self.config.noopt+"""
+LOADER   = """+self.config.fc+"""
+LOADOPTS = """+self.config.ldflags_fc+"""
+#
+# Timer for the SECOND and DSECND routines
+#
+# Default : SECOND and DSECND will use a call to the EXTERNAL FUNCTION ETIME
+# TIMER    = EXT_ETIME
+# For RS6K : SECOND and DSECND will use a call to the EXTERNAL FUNCTION ETIME_
+# TIMER    = EXT_ETIME_
+# For gfortran compiler: SECOND and DSECND will use a call to the INTERNAL FUNCTION ETIME
+# TIMER    = INT_ETIME
+# If your Fortran compiler does not provide etime (like Nag Fortran Compiler, etc...)
+# SECOND and DSECND will use a call to the INTERNAL FUNCTION CPU_TIME
+TIMER    = INT_CPU_TIME
+# If neither of this works...you can use the NONE value... In that case, SECOND and DSECND will always return 0
+# TIMER     = NONE
+#
+#  Configuration LAPACKE: Native C interface to LAPACK
+#  To generate LAPACKE library: type 'make lapackelib'
+#  Configuration file: turned off (default)
+#  Complex types: C99 (default)
+#  Name pattern: mixed case (default)
+#  (64-bit) Data model: LP64 (default)
+#
+# CC is the C compiler, normally invoked with options CFLAGS.
+#
+CC     = """+self.config.cc+"""
+CFLAGS = """+self.config.ccflags+"""
+#
+#  The archiver and the flag(s) to use when building archive (library)
+#  If you system has no ranlib, set RANLIB = echo.
+#
+ARCH     = ar
+ARCHFLAGS= """+self.config.arflags+"""
+RANLIB   = """+self.config.ranlib+"""
+#
+#  The location of BLAS library for linking the testing programs.
+#  The target's machine-specific, optimized BLAS library should be
+#  used whenever possible.
+#
+BLASLIB      = """+self.config.blaslib+"""
+#
+#  Location of the extended-precision BLAS (XBLAS) Fortran library
+#  used for building and testing extended-precision routines.  The
+#  relevant routines will be compiled and XBLAS will be linked only if
+#  USEXBLAS is defined.
+#
+# USEXBLAS    = Yes
+XBLASLIB     =
+# XBLASLIB    = -lxblas
+#
+#  Names of generated libraries.
+#
+LAPACKLIB    = liblapack.a
+TMGLIB       = libtmg.a
+EIGSRCLIB    = libeigsrc.a
+LINSRCLIB    = liblinsrc.a
+LAPACKELIB   = liblapacke.a
 """)
 
         # compile and generate library
         print 'Compile and generate reference LAPACK C interface...',
         sys.stdout.flush()
-        comm = self.make
+        comm = self.make+' lapackelib'
         (output, error, retz) = runShellCommand(comm)
         if retz:
             print "\n\nLAPCWRAPPER: cannot compile LAPACK C interface"
@@ -226,7 +266,11 @@ LAPACKE   = liblapacke.a
         shutil.copy('liblapacke.a',os.path.join(self.prefix,'lib/liblapacke.a'))
 
         # move headers to the include directory
-        shutil.copy('include/lapacke.h',os.path.join(self.prefix,'include/lapacke.h'))
+        shutil.copy('lapacke/include/lapacke.h', os.path.join(self.prefix,'include/lapacke.h'))
+        shutil.copy('lapacke/include/lapacke_config.h', os.path.join(self.prefix,'include/lapacke_config.h'))
+        shutil.copy('lapacke/include/lapacke_utils.h', os.path.join(self.prefix,'include/lapacke_utils.h'))
+        shutil.copy('lapacke/include/lapacke_mangling.h', os.path.join(self.prefix,'include/lapacke_mangling.h'))
+        shutil.copy('lapacke/include/lapacke_mangling_with_flags.h', os.path.join(self.prefix,'include/lapacke_mangling_with_flags.h'))
 
         # set framework variables to point to the freshly installed BLAS library
         self.config.lapclib   = '-L'+os.path.join(self.prefix,'lib')+' -llapacke'
